timespantools.TimespanInventory
===============================

.. autoclass:: abjad.tools.timespantools.TimespanInventory.TimespanInventory

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_abctools {
           graph [label=abctools];
           "abctools.AbjadObject" [color=2,
               group=1,
               label=AbjadObject,
               shape=box];
           "abctools.AbjadObject.AbstractBase" [color=2,
               group=1,
               label=AbstractBase,
               shape=box];
           "abctools.AbjadObject.AbstractBase" -> "abctools.AbjadObject";
       }
       subgraph cluster_datastructuretools {
           graph [label=datastructuretools];
           "datastructuretools.TypedCollection" [color=3,
               group=2,
               label=TypedCollection,
               shape=oval,
               style=bold];
           "datastructuretools.TypedList" [color=3,
               group=2,
               label=TypedList,
               shape=box];
           "datastructuretools.TypedCollection" -> "datastructuretools.TypedList";
       }
       subgraph cluster_timespantools {
           graph [label=timespantools];
           "timespantools.TimespanInventory" [color=black,
               fontcolor=white,
               group=3,
               label=<<B>TimespanInventory</B>>,
               shape=box,
               style="filled, rounded"];
       }
       "__builtin__.object" -> "abctools.AbjadObject.AbstractBase";
       "abctools.AbjadObject" -> "datastructuretools.TypedCollection";
       "datastructuretools.TypedList" -> "timespantools.TimespanInventory";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_contiguous
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_nonoverlapping
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_well_formed
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.append
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.axis
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.clip_timespan_durations
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_and
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_or
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_xor
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_overlap_factor
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_overlap_factor_mapping
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.count
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.count_offsets
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.duration
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.explode
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.extend
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.get_timespan_that_satisfies_time_relation
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.get_timespans_that_satisfy_time_relation
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.has_timespan_that_satisfies_time_relation
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.index
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.insert
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.is_sorted
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.item_class
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.items
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.keep_sorted
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.partition
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.pop
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.reflect
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.remove
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.remove_degenerate_timespans
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.repeat_to_stop_offset
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.reverse
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.rotate
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.round_offsets
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.scale
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.sort
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.split_at_offset
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.split_at_offsets
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.start_offset
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.stop_offset
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.stretch
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.timespan
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.translate
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.translate_offsets
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__and__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__contains__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__delitem__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__eq__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__format__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__getitem__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__hash__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__iadd__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__illustrate__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__iter__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__len__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__ne__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__repr__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__reversed__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__setitem__
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory.__sub__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_contiguous
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_nonoverlapping
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.all_are_well_formed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.axis
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.duration
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.is_sorted
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.item_class
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.items
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.start_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.timespan
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.keep_sorted
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.append
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.clip_timespan_durations
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_and
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_or
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_logical_xor
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_overlap_factor
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.compute_overlap_factor_mapping
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.count
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.count_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.explode
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.extend
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.get_timespan_that_satisfies_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.get_timespans_that_satisfy_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.has_timespan_that_satisfies_time_relation
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.index
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.insert
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.partition
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.pop
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.reflect
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.remove
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.remove_degenerate_timespans
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.repeat_to_stop_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.reverse
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.rotate
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.round_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.scale
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.sort
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.split_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.split_at_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.stretch
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.translate
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.translate_offsets
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__and__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__hash__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__illustrate__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__len__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanInventory.TimespanInventory.__sub__
   :noindex:
